@@ -5,7 +5,7 @@ module Database.PostgreSQL.Embedded.Postgres
     ) where
 
 import           Control.Exception                     (SomeException, try)
-import           Data.Conduit.Shell                    (rm, run, shell)
+import           System.Process                        (system)
 import           Data.List                             (isInfixOf)
 import           Data.Monoid                           ((<>))
 import           System.Directory                      (doesDirectoryExist)
@@ -15,6 +15,7 @@ import           System.Info                           (os)
 
 import           Database.PostgreSQL.Embedded.Download
 import           Database.PostgreSQL.Embedded.Types
+import           Database.PostgreSQL.Embedded.Exec
 
 {-|
 Starts PostgreSQL instance with given config.
@@ -22,21 +23,22 @@ Starts PostgreSQL instance with given config.
 Returns @RuntimeConfig@ that is required for @stopPostgres@.
 -}
 startPostgres :: StartupConfig -> DBConfig -> IO RuntimeConfig
-startPostgres (StartupConfig сlean version_) dConfig@(DBConfig p u) = do
-    e <- downloadPostgres getOS version_
+startPostgres (StartupConfig сlean version_ silent_) dConfig@(DBConfig p u) = do
+    let execSystem = if silent_ then systemSilent else system
+    e <- downloadPostgres silent_ getOS version_
     let d = e </> "data"
     exists <- doesDirectoryExist d
-    if exists && not сlean then do
+    _ <- if exists && not сlean then do
         putStrLn $ "Directory " <> d <> " must not exist"
         exitFailure
-    else run $ rm "-rf" d
+    else execSystem $ "rm" <> " -rf " <> d
 
-    run $ do
-        shell $ e </> "bin" </> "initdb" <> " -A trust -U " <> u <> " -D " <> d <> " -E UTF-8"
-        shell $ e </> "bin" </> "pg_ctl" <> " -D " <> d <> " -o \"-F -p " <>
+    _ <- do
+        _ <- execSystem $ e </> "bin" </> "initdb" <> " -A trust -U " <> u <> " -D " <> d <> " -E UTF-8"
+        execSystem $ e </> "bin" </> "pg_ctl" <> " -w " <> " -D " <> d <> " -o \"-F -p " <>
             show p <> "\"" <> " -l " <> (e </> "log") <> " start"
 
-    let r = RuntimeConfig e d
+    let r = RuntimeConfig e d silent_
     checkPostgresStarted r dConfig
     return r
 
@@ -52,16 +54,18 @@ Stops PostgreSQL instance.
 Doesn't remove data directory.
 -}
 stopPostgres :: RuntimeConfig -> IO ()
-stopPostgres (RuntimeConfig e d) = run $
-        shell $ e </> "bin" </> "pg_ctl" <> " -D " <> d <> " stop" <>
-                " -m fast -t 5 -w"
+stopPostgres (RuntimeConfig e d s) = do
+        let execSystem = if s then systemSilent else system
+        _ <- execSystem $ e </> "bin" </> "pg_ctl" <> " -D " <> d <> " stop" <> " -m fast -t 5 -w"
+        return ()
 
 checkPostgresStarted :: RuntimeConfig -> DBConfig -> IO ()
-checkPostgresStarted (RuntimeConfig e _) (DBConfig p _) = checkPostgresStarted_ 10 >>= \_ -> return ()
+checkPostgresStarted (RuntimeConfig e _ s) (DBConfig p _) = checkPostgresStarted_ 10 >>= \_ -> return ()
     where
         checkPostgresStarted_ :: Int -> IO Bool
         checkPostgresStarted_ n = do
-            let check = run $ shell (e </> "bin" </> "pg_isready" <> " -p " <> show p <> " -h localhost") >>= \_ -> return True
+            let execSystem = if s then systemSilent else system
+            let check = execSystem (e </> "bin" </> "pg_isready" <> " -p " <> show p <> " -h localhost") >>= \_ -> return True
 
             res <- try check :: IO (Either SomeException Bool)
             let retry = if n > 0 then checkPostgresStarted_ (n - 1)
