@@ -1,19 +1,19 @@
 import           Data.ByteString.Char8        (pack)
-import           Data.Conduit.Shell           (rm, run)
 import           Data.Monoid                  ((<>))
 import           Data.String                  (fromString)
 import           Database.PostgreSQL.Simple   (Only (..), connectPostgreSQL,
                                                query_)
 import           System.FilePath.Posix        ((</>))
+import           System.Process               (system)
 
 import           Database.PostgreSQL.Embedded
 
 main :: IO ()
 main = do
-    let sConfig = StartupConfig True (Version "9.6.5-1")
+    let sConfig = StartupConfig True (Version "9.6.5-1") False
     let dConfig = DBConfig 46782 "postgres"
 
-    run $ rm "-rf" $ "~/.postgres-embedded/" </> "9.6.5-1"
+    system $ "rm" <> " -rf " <> ("~/.postgres-embedded/" </> "9.6.5-1")
 
     -- Start Postgres downloading distribution
     rc <- startPostgres sConfig dConfig
